==> locus-0.84.tar.gz: locus-0.84/lib/myfndt/cstr.cpp <==
#include "cstr.h"
#include "string.h"

const int DString::MaxAllowedLength = 32748;
    // for gcc; might be a bit bigger, but less than 32756

#if defined(_MSC_VER)
DString::DString()
{
}

DString::DString(const CString &s):
	CString(s)
{
}

DString::DString(const char *cp):
	CString(cp)
{
}
#endif

#if defined(__BORLANDC__)
int DString::operator == (const DString *Other) const
{
	return *this == *Other;
}

int DString::operator < (const DString *Other) const
{
	return *this < *Other;
}

int DString::operator > (const DString *Other) const
{
	return *this > *Other;
}
#endif

#if 0
int DString::Compare(const DString &Other) const
/*{   char stub = 0;

    const char *p = c_str();
    if (!p)
	  p = &stub;
    const char *q = c_str();
    if (!q)
	  q = &stub;

    return strcmp(p, q);
}*/
{
    return ::compare(*this, Other);
    /* this (the default) does not work for 8-bit strings, but strcmp comparison
	  does not work for STL */
}
#endif

unsigned int DString::HashValue() const 
{ 
#if defined(__BORLANDC__)
     return hash(); 
#else
	if (!GetLength())
	     return 0;
	else
	     return operator [](0);
#endif
}

#if defined(_MSC_VER) 
char &DString::operator[](int nIndex)
{
	CopyBeforeWrite();
	return *(const_cast<char *>(const_cast<DString *>(
			this)->operator LPCTSTR()) + nIndex);
}
#endif

#if defined(__GNUG__)
int DString::operator == (const DString &Other) const
{
    return !strcmp(c_str(), Other.c_str());
}

int DString::operator < (const DString &Other) const
{
    return strcmp(c_str(), Other.c_str()) < 0;
}

int DString::operator > (const DString &Other) const
{
    return strcmp(c_str(), Other.c_str()) > 0;
}

int DString::operator != (const DString &Other) const
{
    return strcmp(c_str(), Other.c_str());
}

int DString::operator <= (const DString &Other) const
{
    return strcmp(c_str(), Other.c_str()) <= 0;
}

int DString::operator >= (const DString &Other) const
{
    return strcmp(c_str(), Other.c_str()) >= 0;
}

#endif

==> locus-0.88.tar.gz: locus-0.88/lib/myfndt/cstr.cpp <==
#include "cstr.h"
#include "string.h"

const int DString::MaxAllowedLength = 32748;
    // for gcc; might be a bit bigger, but less than 32756

#if defined(_MSC_VER)
DString::DString()
{
}

DString::DString(const CString &s):
	CString(s)
{
}

DString::DString(const char *cp):
	CString(cp)
{
}
#endif

#if defined(__BORLANDC__)
int DString::operator == (const DString *Other) const
{
	return *this == *Other;
}

int DString::operator < (const DString *Other) const
{
	return *this < *Other;
}

int DString::operator > (const DString *Other) const
{
	return *this > *Other;
}
#endif

#if 0
int DString::Compare(const DString &Other) const
/*{   char stub = 0;

    const char *p = c_str();
    if (!p)
	  p = &stub;
    const char *q = c_str();
    if (!q)
	  q = &stub;

    return strcmp(p, q);
}*/
{
    return ::compare(*this, Other);
    /* this (the default) does not work for 8-bit strings, but strcmp comparison
	  does not work for STL */
}
#endif

unsigned int DString::HashValue() const 
{ 
#if defined(__BORLANDC__)
     return hash(); 
#else
	if (!GetLength())
	     return 0;
	else
	     return operator [](0);
#endif
}

#if defined(_MSC_VER) 
char &DString::operator[](int nIndex)
{
	CopyBeforeWrite();
	return *(const_cast<char *>(const_cast<DString *>(
			this)->operator LPCTSTR()) + nIndex);
}
#endif

#if defined(__GNUG__) && !defined(NATIVE_GPLUSPLUS_STRING_COMPARE)
int DString::operator == (const DString &Other) const
{
    return !strcmp(c_str(), Other.c_str());
}

int DString::operator < (const DString &Other) const
{
    return strcmp(c_str(), Other.c_str()) < 0;
}

int DString::operator > (const DString &Other) const
{
    return strcmp(c_str(), Other.c_str()) > 0;
}

int DString::operator != (const DString &Other) const
{
    return strcmp(c_str(), Other.c_str());
}

int DString::operator <= (const DString &Other) const
{
    return strcmp(c_str(), Other.c_str()) <= 0;
}

int DString::operator >= (const DString &Other) const
{
    return strcmp(c_str(), Other.c_str()) >= 0;
}

#endif
